@@ -12,6 +12,7 @@ import (
 	"github.com/onsi/ginkgo"
 	"github.com/onsi/gomega"
 
+	"k8s.io/apimachinery/pkg/api/meta"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/util/rand"
 	"k8s.io/apimachinery/pkg/util/wait"
@@ -161,6 +162,23 @@ var _ = ginkgo.Describe("Loopback registration [development]", func() {
 		})
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 
+		sa := &corev1.ServiceAccount{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: nsName,
+				Name:      "spoke-agent-sa",
+			},
+		}
+		err = wait.Poll(1*time.Second, 5*time.Second, func() (bool, error) {
+			var err error
+			_, err = hubClient.CoreV1().ServiceAccounts(nsName).Create(context.TODO(), sa, metav1.CreateOptions{})
+			if err != nil {
+				return false, err
+			}
+
+			return true, nil
+		})
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+
 		var (
 			deployment         *unstructured.Unstructured
 			deploymentResource = schema.GroupVersionResource{
@@ -183,43 +201,6 @@ var _ = ginkgo.Describe("Loopback registration [development]", func() {
 		})
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 
-		secret := &corev1.Secret{
-			ObjectMeta: metav1.ObjectMeta{
-				Namespace: nsName,
-				Name:      "hub-kubeconfig-secret",
-			},
-			Data: map[string][]byte{
-				"placeholder": []byte("YWRtaW4="),
-			},
-		}
-		err = wait.Poll(1*time.Second, 5*time.Second, func() (bool, error) {
-			var err error
-			_, err = hubClient.CoreV1().Secrets(nsName).Create(context.TODO(), secret, metav1.CreateOptions{})
-			if err != nil {
-				return false, err
-			}
-
-			return true, nil
-		})
-		gomega.Expect(err).ToNot(gomega.HaveOccurred())
-
-		sa := &corev1.ServiceAccount{
-			ObjectMeta: metav1.ObjectMeta{
-				Namespace: nsName,
-				Name:      "spoke-agent-sa",
-			},
-		}
-		err = wait.Poll(1*time.Second, 5*time.Second, func() (bool, error) {
-			var err error
-			_, err = hubClient.CoreV1().ServiceAccounts(nsName).Create(context.TODO(), sa, metav1.CreateOptions{})
-			if err != nil {
-				return false, err
-			}
-
-			return true, nil
-		})
-		gomega.Expect(err).ToNot(gomega.HaveOccurred())
-
 		var (
 			csrs      *certificatesv1beta1.CertificateSigningRequestList
 			csrClient = hubClient.CertificatesV1beta1().CertificateSigningRequests()
@@ -305,12 +286,7 @@ var _ = ginkgo.Describe("Loopback registration [development]", func() {
 				return false, err
 			}
 
-			condition := helpers.FindManagedClusterCondition(managedCluster.Status.Conditions, clusterv1.ManagedClusterConditionHubAccepted)
-			if condition == nil {
-				return false, nil
-			}
-
-			if helpers.IsConditionTrue(condition) {
+			if meta.IsStatusConditionTrue(managedCluster.Status.Conditions, clusterv1.ManagedClusterConditionHubAccepted) {
 				return true, nil
 			}
 
@@ -326,9 +302,7 @@ var _ = ginkgo.Describe("Loopback registration [development]", func() {
 				return false, err
 			}
 
-			condition := helpers.FindManagedClusterCondition(managedCluster.Status.Conditions, clusterv1.ManagedClusterConditionJoined)
-
-			return helpers.IsConditionTrue(condition), nil
+			return meta.IsStatusConditionTrue(managedCluster.Status.Conditions, clusterv1.ManagedClusterConditionJoined), nil
 		})
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 
@@ -339,8 +313,7 @@ var _ = ginkgo.Describe("Loopback registration [development]", func() {
 				return false, err
 			}
 
-			condition := helpers.FindManagedClusterCondition(managedCluster.Status.Conditions, clusterv1.ManagedClusterConditionAvailable)
-			return helpers.IsConditionTrue(condition), nil
+			return meta.IsStatusConditionTrue(managedCluster.Status.Conditions, clusterv1.ManagedClusterConditionAvailable), nil
 		})
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 
@@ -388,8 +361,7 @@ var _ = ginkgo.Describe("Loopback registration [development]", func() {
 				return false, err
 			}
 
-			condition := helpers.FindManagedClusterCondition(managedCluster.Status.Conditions, clusterv1.ManagedClusterConditionAvailable)
-			return helpers.IsConditionTrue(condition), nil
+			return meta.IsStatusConditionTrue(managedCluster.Status.Conditions, clusterv1.ManagedClusterConditionAvailable), nil
 		})
 		gomega.Expect(err).ToNot(gomega.HaveOccurred())
 	})
